@@ -8,10 +8,7 @@ use crypto_rest_client::{fetch_l2_snapshot, fetch_l3_snapshot};
 use fslock::LockFile;
 use log::*;
 
-use crate::{
-    utils::{cmc_rank::sort_by_cmc_rank, get_hot_spot_symbols},
-    Message, MessageType,
-};
+use crate::{utils::cmc_rank::sort_by_cmc_rank, Message, MessageType};
 
 fn get_lock_file(exchange: &str, market_type: MarketType) -> Option<LockFile> {
     let filename = if exchange == "bitmex" {
@@ -102,11 +99,11 @@ fn get_cooldown_time_per_request(exchange: &str) -> Duration {
     let millis = match exchange {
         "binance" => 500,      // spot weitht 1200, contract weight 2400
         "bitget" => 100,       // 20 requests per 2 seconds
-        "bithumb" => 8,        // 135 requests per 1 second for public APIs
+        "bithumb" => 8 * 10, // 135 requests per 1 second for public APIs, multiplied by 10 to reduce its frequency
         "bitmex" => 2000, // 60 requests per minute on all routes (reduced to 30 when unauthenticated)
-        "bitstamp" => 750, // 8000 requests per 10 minutes, but bitstamp orderbook is too big, need to reduce its frequency
-        "bitz" => 34,      // no more than 30 times within 1 second
-        "bybit" => 20 * 10, // 50 requests per second continuously for 2 minutes, 10x since it's too fast
+        "bitstamp" => 75 * 10, // 8000 requests per 10 minutes, but bitstamp orderbook is too big, need to reduce its frequency
+        "bitz" => 34,          // no more than 30 times within 1 second
+        "bybit" => 20 * 10, // 50 requests per second continuously for 2 minutes, multiplied by 10 to reduce its frequency
         "coinbase_pro" => 100, //  10 requests per second
         "deribit" => 50,    // 20 requests per second
         "gate" => 4,        // 300 read operations per IP per second
@@ -145,12 +142,7 @@ pub(crate) fn crawl_snapshot(
     let mut lock = get_lock_file(exchange, market_type);
     loop {
         let mut real_symbols = if is_empty {
-            if market_type == MarketType::Spot {
-                let spot_symbols = fetch_symbols_retry(exchange, market_type);
-                get_hot_spot_symbols(exchange, &spot_symbols)
-            } else {
-                fetch_symbols_retry(exchange, market_type)
-            }
+            fetch_symbols_retry(exchange, market_type)
         } else {
             symbols.unwrap().to_vec()
         };
